package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.system.domain.ContractTable;
import com.ruoyi.system.domain.GradTable;
import com.ruoyi.system.domain.dto.QueryEntity;

/**
 * A类证书Mapper接口
 *
 * @author ruoyi
 * @date 2022-12-05
 */
public interface GradTableMapper
{
    /**
     * 查询A类证书
     *
     * @param id A类证书主键
     * @return A类证书
     */
    public GradTable selectGradTableById(Integer id);

    /**
     * 查询A类证书列表
     *
     * @param gradTable A类证书
     * @return A类证书集合
     */
    public List<GradTable> selectGradTableList(GradTable gradTable);

    /**
     * 新增A类证书
     *
     * @param gradTable A类证书
     * @return 结果
     */
    public int insertGradTable(GradTable gradTable);

    /**
     * 修改A类证书
     *
     * @param gradTable A类证书
     * @return 结果
     */
    public int updateGradTable(GradTable gradTable);

    /**
     * 删除A类证书
     *
     * @param id A类证书主键
     * @return 结果
     */
    public int deleteGradTableById(Integer id);

    /**
     * 批量删除A类证书
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGradTableByIds(Integer[] ids);

    GradTable selectInfoByCertId(String certId);

    GradTable selectInfoByQuery(QueryEntity entity);
}
