package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.ContractTable;
import com.ruoyi.system.domain.dto.QueryEntity;
import com.ruoyi.system.service.GradDTOService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GradTable;
import com.ruoyi.system.service.IGradTableService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * A类证书Controller
 *
 * @author ruoyi
 * @date 2022-12-05
 */
@RestController
@RequestMapping("/system/grad")
public class GradTableController extends BaseController
{
    @Autowired
    private IGradTableService gradTableService;

    @Autowired
    private GradDTOService gradDTOService;

    /**
     * 查询A类证书列表
     */
    @PreAuthorize("@ss.hasPermi('system:grad:list')")
    @GetMapping("/list")
    public TableDataInfo list(GradTable gradTable)
    {
        startPage();
        List<GradTable> list = gradTableService.selectGradTableList(gradTable);
        return getDataTable(list);
    }

    /**
     * 导出A类证书列表
     */
    @PreAuthorize("@ss.hasPermi('system:grad:export')")
    @Log(title = "A类证书", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GradTable gradTable)
    {
        List<GradTable> list = gradTableService.selectGradTableList(gradTable);
        ExcelUtil<GradTable> util = new ExcelUtil<GradTable>(GradTable.class);
        util.exportExcel(response, list, "A类证书数据");
    }

    /**
     * 获取A类证书详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:grad:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(gradTableService.selectGradTableById(id));
    }

    @PostMapping("/getInfoByCode")
    public AjaxResult getInfoByCode(@RequestBody QueryEntity queryEntity)
    {
        return success(gradDTOService.getInfo(queryEntity));
    }

    /**
     * 新增A类证书
     */
    @PreAuthorize("@ss.hasPermi('system:grad:add')")
    @Log(title = "A类证书", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GradTable gradTable)
    {
        return toAjax(gradTableService.insertGradTable(gradTable));
    }

    /**
     * 修改A类证书
     */
    @PreAuthorize("@ss.hasPermi('system:grad:edit')")
    @Log(title = "A类证书", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GradTable gradTable)
    {
        return toAjax(gradTableService.updateGradTable(gradTable));
    }

    /**
     * 删除A类证书
     */
    @PreAuthorize("@ss.hasPermi('system:grad:remove')")
    @Log(title = "A类证书", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(gradTableService.deleteGradTableByIds(ids));
    }

    /**
     * 导入excel
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @Log(title = "A类证书", businessType = BusinessType.IMPORT) // todo
    @PreAuthorize("@ss.hasPermi('collegeManage:studentBase:import')") // todo
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<GradTable> util = new ExcelUtil<>(GradTable.class); // todo
        List<GradTable> stuList = util.importExcel(file.getInputStream()); // todo
        String operName = getUsername();
        String message = gradTableService.importCon(stuList, updateSupport, operName); // todo
        return AjaxResult.success(message);
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<GradTable> util = new ExcelUtil<>(GradTable.class); // todo
        util.importTemplateExcel(response, "A类证书信息");
    }
}
